@@ -1,9 +1,10 @@
-from typing import List
+from typing import List, Iterable, Dict
 
 from rest_framework.request import Request
 
 from bridger.buttons.bases import ButtonConfig as Button
 from bridger.metadata.mixins import BridgerMetadataMixin
+from bridger.utils.itertools import uniquify_dict_iterable
 
 
 class CustomInstanceButtonMetadata(BridgerMetadataMixin):
@@ -27,7 +28,7 @@ class CustomInstanceButtonMetadataMixin:
             for button in buttons:
                 button.request = request
                 button_list.append(dict(button))
-            return button_list
+            return uniquify_dict_iterable(button_list, "key")
         else:
             buttons = self.get_custom_list_instance_buttons(
                 request=request,
@@ -37,4 +38,4 @@ class CustomInstanceButtonMetadataMixin:
             for button in buttons:
                 button.request = request
                 button_list.append(dict(button))
-            return button_list
+            return uniquify_dict_iterable(button_list, "key")
